@@ -9,10 +9,6 @@ role = silk.lib.get_role()
 root = silk.lib.get_site_root(os.getcwd())
 config = silk.lib.get_config(root, role)
 
-#mount the wsgi app
-wsgi_app = cherrypy.lib.attributes(config['wsgi_app'].replace(':', '.'))
-cherrypy.tree.graft(wsgi_app, '')
-
 if config['static_dirs']:
     for static_dir in config['static_dirs']:
         # Mount each of our static dirs as its own app in the cherrypy tree.
@@ -21,7 +17,11 @@ if config['static_dirs']:
         sys_path = os.path.join(root, static_dir['system_path'])
         cherry_conf = {'/': {'tools.staticdir.on': True,
                              'tools.staticdir.dir': sys_path,}}
-        cherrypy.tree.mount(wsgi_app, script_name=url_path, config=cherry_conf)
+        cherrypy.tree.mount(None, script_name=url_path, config=cherry_conf)
+
+#mount the wsgi app
+wsgi_app = cherrypy.lib.attributes(config['wsgi_app'].replace(':', '.'))
+cherrypy.tree.graft(wsgi_app, '')
 
 sys.path.append(root)
 os.chdir(root)
